from django.conf import settings
from django.conf.urls.static import static
from django.urls import re_path


if settings.ALDRYN_DJANGO_ENABLE_GIS:
    from django.contrib.gis import admin
else:
    from django.contrib import admin


admin.autodiscover()

urlpatterns = [
    re_path(r'^admin/', admin.site.urls),
]

# serve static files differently on local development
if settings.IS_RUNNING_DEVSERVER and not settings.MEDIA_URL_IS_ON_OTHER_DOMAIN:
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)



import mimetypes
import shutil
import subprocess

from django.conf import settings
from django.contrib.staticfiles.finders import get_finders
from django.core.files import File
from django.core.files.temp import NamedTemporaryFile
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = 'Optimize static images prior to collectstatic'
    setting_names = [
        'STATIC_IMAGES_OPTIMIZE_COMMAND',
        'THUMBNAIL_OPTIMIZE_COMMAND',
    ]

    def get_settings(self):
        for setting_name in self.setting_names:
            try:
                return getattr(settings, setting_name)
            except AttributeError:
                pass
        else:
            return {}

    def handle(self, *args, **options):
        ignore_patterns = ['CVS', '.*', '*~']
        base_path = settings.BASE_DIR.rstrip('/') + '/'
        optimize_commands = self.get_settings()

        for finder in get_finders():
            for path, storage in finder.list(ignore_patterns):
                if not storage.path(path).startswith(base_path):
                    # Do not process images found in static dirs of third party
                    # apps.
                    continue
                mimetype = mimetypes.guess_type(path)[0]
                if not mimetype:
                    # Unknown mime type, ignore the file.
                    continue
                generic_type, image_type = mimetype.split('/', 1)
                if generic_type != 'image':
                    # Only process images.
                    continue
                if image_type in optimize_commands:
                    self.optimize(
                        storage,
                        path,
                        image_type,
                        optimize_commands[image_type],
                    )

    def optimize(self, storage, path, image_type, command):
        with NamedTemporaryFile() as temp_image:
            # Copy the image to the temporary file
            with storage.open(path, 'r+') as image:
                shutil.copyfileobj(image, temp_image)
            temp_image.flush()
            temp_image.seek(0)

            # Optimize the image
            optimize_command = command.format(filename=temp_image.name)
            self.stdout.write('>>> {}'.format(optimize_command))
            subprocess.check_call(optimize_command, shell=True)
            self.stdout.write('')

            # Save the image back from the temporary file into the storage
            with open(temp_image.name) as fh:
                storage.delete(path)
                storage.save(path, File(fh))



import gzip
import os
import shutil
import warnings

from django.conf import settings
from django.contrib.staticfiles.storage import staticfiles_storage
from django.core.management import call_command
from django.core.management.base import BaseCommand

from aldryn_django.storage import GZippedStaticFilesMixin


def iterfiles(root):
    for dirpath, dirnames, filenames in os.walk(root):
        for filename in filenames:
            yield os.path.join(dirpath, filename)


class Command(BaseCommand):
    help = 'Collect static files by following Aldryn conventions'
    gzip_ext = frozenset([
        '.html',
        '.css',
        '.js',
        '.json',
        '.svg',
        '.txt',
    ])

    def handle(self, *args, **options):
        warnings.warn((
            'aldryn_collectstatic is deprecated, please use a staticfiles\n'
            'storage backend supporting file gzipping, such as\n'
            'aldryn_django.storage.GZippedStaticFilesStorage, and just call\n'
            'the collectstatic management command instead.'
        ), DeprecationWarning)

        # Defer static collection to Django
        call_command(
            'collectstatic',
            interactive=False,
            stdout=self.stdout,
        )

        if isinstance(staticfiles_storage, GZippedStaticFilesMixin):
            # No need to run gzipping twice if the currently configured storage
            # backend already does it
            return

        # Gzip all files as appropriate
        for path_in in iterfiles(settings.STATIC_ROOT):
            if os.path.splitext(path_in)[1] in self.gzip_ext:
                path_out = path_in + '.gz'
                with open(path_in, 'rb') as f_in:
                    self.stdout.write('Compressing {}...'.format(path_in))
                    with gzip.open(path_out, 'wb') as f_out:
                        shutil.copyfileobj(f_in, f_out)
